@@ -1002,8 +1002,8 @@ sub LoadDefaults {
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
         'thirdparty/jquery-ui-1.13.3/jquery-ui.js',
         'thirdparty/jquery-pubsub/pubsub.js',
-        'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/jquery-jstree-3.3.8/jquery.jstree.js',
+        'thirdparty/nunjucks-3.2.3/nunjucks.min.js',
         'Core.Init.js',
         'Core.Debug.js',
         'Core.Exception.js',
@@ -1041,8 +1041,8 @@ sub LoadDefaults {
         'thirdparty/jquery-ui-touch-punch-0.2.3/jquery.ui.touch-punch.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
         'thirdparty/jquery-pubsub/pubsub.js',
-        'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/jquery-jstree-3.3.8/jquery.jstree.js',
+        'thirdparty/nunjucks-3.2.3/nunjucks.min.js',
         'thirdparty/jscolor-2.4.6/jscolor.js',
         'Core.Init.js',
         'Core.JavaScriptEnhancements.js',
@@ -1878,7 +1878,7 @@ via the Preferences button after logging in.
         GroupRo      => [],
         IconBig     => 'fa-plug',
         IconSmall => '',
-        Description => Translatable('Update and extend your system with software packages.'),
+        Description => Translatable('Manage add-ons.'),
         Module      => 'Kernel::Output::HTML::NavBar::ModuleAdmin',
         Name        => Translatable('Package Manager'),
         Block => 'Administration',
