@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -8,7 +8,7 @@
 # --
 
 package Kernel::System::DB;
-## nofilter(TidyAll::Plugin::OTRS::Perl::Pod::FunctionPod)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Pod::FunctionPod)
 
 use strict;
 use warnings;
@@ -20,11 +20,13 @@ use Kernel::System::VariableCheck qw(:all);
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::Cache',
+    'Kernel::System::DateTime',
     'Kernel::System::Encode',
     'Kernel::System::Log',
     'Kernel::System::Main',
-    'Kernel::System::DateTime',
     'Kernel::System::Storable',
+    'Kernel::System::XML',
 );
 
 our $UseSlaveDB = 0;
@@ -292,6 +294,78 @@ sub Version {
     return $Version;
 }
 
+=head2 CheckRequiredDatabaseVersion()
+
+Check if the required database version is installed or not.
+
+    my %VersionInfo = $DBObject->CheckRequiredDatabaseVersion();
+
+Returns:
+
+    my %VersionInfo = (
+        'DatabaseType'       => 'MariaDB',
+        'VersionString'      => 'MariaDB 10.6.12',
+        'InstalledVersion'   => '10.6.12',
+        'MinimumVersion'     => '5.0.0',
+        'RequirementsPassed' => 1,
+    );
+
+=cut
+
+sub CheckRequiredDatabaseVersion {
+    my ( $Self, %Param ) = @_;
+
+    my $LogObject = $Kernel::OM->Get('Kernel::System::Log');
+
+    # Use dotted-decimal version formats, since version->parse() might not work as you expect it to.
+    #
+    #   $Version   version->parse($Version)
+    #   ---------   -----------------------
+    #   1.23        v1.230.0
+    #   "1.23"      v1.230.0
+    #   v1.23       v1.23.0
+    #   "v1.23"     v1.23.0
+    #   "1.2.3"     v1.2.3
+    #   "v1.2.3"    v1.2.3
+    my %MinimumDatabaseVersion = (
+        MySQL      => '8.0.0',
+        MariaDB    => '10.3.0',
+        PostgreSQL => '12.0.0',
+        Oracle     => '19.0.0',
+    );
+
+    my $VersionString = $Self->Version();
+
+    my $DatabaseType;
+    my $DatabaseVersion;
+    if ( $VersionString =~ m{ \A (MySQL|MariaDB|Oracle|PostgreSQL) \s+ ([0-9.]+) \z }xms ) {
+        $DatabaseType    = $1;
+        $DatabaseVersion = $2;
+    }
+
+    if ( !$DatabaseType || !$DatabaseVersion ) {
+        $LogObject->Log(
+            Priority => 'error',
+            Message  => 'Not able to detect database version!',
+        );
+        return;
+    }
+
+    my %Result = (
+        VersionString      => $VersionString,
+        DatabaseType       => $DatabaseType,
+        InstalledVersion   => $DatabaseVersion,
+        MinimumVersion     => $MinimumDatabaseVersion{$DatabaseType},
+        RequirementsPassed => 1,
+    );
+
+    if ( version->parse($DatabaseVersion) < version->parse( $MinimumDatabaseVersion{$DatabaseType} ) ) {
+        $Result{RequirementsPassed} = 0;
+    }
+
+    return %Result;
+}
+
 =head2 Quote()
 
 to quote sql parameters
@@ -349,6 +423,32 @@ sub Quote {
         return $Text;
     }
 
+    # quote DateTime
+    if ( $Type eq 'DateTime' ) {
+        if ( $Text !~ m{\A(\d\d\d\d)-(\d\d|\d)-(\d\d|\d) (\d\d|\d):(\d\d|\d):(\d\d|\d)\z} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Caller   => 1,
+                Priority => 'error',
+                Message  => "Invalid DateTime in query '$Text'!",
+            );
+            return;
+        }
+        return $Text;
+    }
+
+    # quote Date
+    if ( $Type eq 'Date' ) {
+        if ( $Text !~ m{\A(\d\d\d\d)-(\d\d|\d)-(\d\d|\d)\z} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Caller   => 1,
+                Priority => 'error',
+                Message  => "Invalid Date in query '$Text'!",
+            );
+            return;
+        }
+        return $Text;
+    }
+
     # quote like strings
     if ( $Type eq 'Like' ) {
         return ${ $Self->{Backend}->Quote( \$Text, $Type ) };
@@ -826,6 +926,76 @@ sub ListTables {
     return @Tables;
 }
 
+=head2 GetSystemTables
+
+Retrieves tables of Znuny and optionally its installed packages and ignores any other tables that
+might have been added manually to the database.
+
+    my @SystemTables = $DBObject->GetSystemTables(
+        IncludePackageTables => 1, # Also include tables of installed packages
+    );
+
+Returns array with system table names.
+
+=cut
+
+sub GetSystemTables {
+    my ( $Self, %Param ) = @_;
+
+    my $ConfigObject  = $Kernel::OM->Get('Kernel::Config');
+    my $PackageObject = $Kernel::OM->Get('Kernel::System::Package');
+    my $XMLObject     = $Kernel::OM->Get('Kernel::System::XML');
+
+    #
+    # Assemble Znuny tables.
+    #
+    my $SQLDirectory   = $ConfigObject->Get('Home') . '/scripts/database';
+    my $SchemaFilePath = $SQLDirectory . '/' . 'schema.xml';
+
+    my $SchemaXML = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+        Location => $SchemaFilePath,
+    );
+    my @SchemaXML = $XMLObject->XMLParse(
+        String => $SchemaXML,
+    );
+
+    my @TableTags = grep {
+        defined $_->{Tag}
+            && $_->{Tag} eq 'Table'
+            && $_->{TagType} eq 'Start'
+    } @SchemaXML;
+    my @SystemTables = sort map { $_->{Name} } @TableTags;
+
+    return @SystemTables if !$Param{IncludePackageTables};
+
+    #
+    # Assemble tables of installed packages.
+    #
+    my @Packages = $Kernel::OM->Get('Kernel::System::Package')->RepositoryList();
+    PACKAGE:
+    for my $Package (@Packages) {
+        my $DatabaseInstall = $Package->{DatabaseInstall};
+        next PACKAGE if !IsHashRefWithData($DatabaseInstall);
+
+        for my $Type ( sort keys %{$DatabaseInstall} ) {
+            my @PackageTableTags = grep {
+                defined $_->{Tag}
+                    && $_->{Tag} eq 'TableCreate'
+                    && $_->{TagType} eq 'Start'
+            } @{ $DatabaseInstall->{$Type} };
+            my @PackageTables = sort map { $_->{Name} } @PackageTableTags;
+
+            push @SystemTables, @PackageTables;
+        }
+    }
+
+    # Ensure that every table is unique.
+    my %SystemTables = map { $_ => 1 } @SystemTables;
+    @SystemTables = sort keys %SystemTables;
+
+    return @SystemTables;
+}
+
 =head2 GetColumnNames()
 
 to retrieve the column names of a database statement
@@ -852,6 +1022,72 @@ sub GetColumnNames {
     return @Result;
 }
 
+=head2 GetColumnMaxLengths()
+
+This method is used to retrieve the maximum length of a column in the database.
+
+    my %ColumnMaxLength = $DBObject->GetColumnMaxLengths(
+        Table => "customer_user",
+    );
+
+=cut
+
+sub GetColumnMaxLengths {
+    my ( $Self, %Param ) = @_;
+
+    my $LogObject   = $Kernel::OM->Get('Kernel::System::Log');
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+    NEEDED:
+    for my $Needed (qw(Table)) {
+
+        next NEEDED if defined $Param{$Needed};
+
+        $LogObject->Log(
+            Priority => 'error',
+            Message  => "Parameter '$Needed' is needed!",
+        );
+        return;
+    }
+
+    my $Cache = $CacheObject->Get(
+        Type => 'DB',                                  # only [a-zA-Z0-9_] chars usable
+        Key  => 'ColumnMaxLength::' . $Param{Table},
+    );
+    return %{$Cache} if $Cache;
+
+    my $SQL = "SELECT column_name, character_maximum_length FROM information_schema.columns WHERE table_name = ?";
+
+    # This is a workaround for Oracle, because the information_schema.columns table is not available.
+    if ( $Self->{'DB::Type'} eq 'oracle' ) {
+        $Param{Table} = uc $Param{Table};
+        $SQL = "SELECT column_name, data_length FROM user_tab_columns WHERE table_name = ?";
+    }
+
+    $Self->Prepare(
+        SQL  => $SQL,
+        Bind => [ \$Param{Table} ],
+    );
+
+    my %ColumnMaxLength;
+    while ( my @Row = $Self->FetchrowArray() ) {
+        if ( $Self->{'DB::Type'} eq 'oracle' ) {
+            $Row[0] = lc $Row[0];
+            $Row[1] = lc $Row[1];
+        }
+        $ColumnMaxLength{ $Row[0] } = $Row[1];
+    }
+
+    $CacheObject->Set(
+        Type  => 'DB',
+        Key   => 'ColumnMaxLength::' . $Param{Table},
+        Value => \%ColumnMaxLength,
+        TTL   => 60 * 60 * 24 * 1,
+    );
+
+    return %ColumnMaxLength;
+}
+
 =head2 SelectAll()
 
 returns all available records of a SELECT statement.
@@ -1111,7 +1347,7 @@ generate SQL condition query based on a search expression
         Key          => 'some_col',
         Value        => '(ABC+DEF)',
         SearchPrefix => '',
-        SearchSuffix => '*'
+        SearchSuffix => '*',
         Extended     => 1, # use also " " as "&&", e.g. "bob smith" -> "bob&&smith"
     );
 
@@ -1140,7 +1376,7 @@ generate SQL condition query based on a search expression
     return the SQL String with ?-values and a array with values references:
 
     $BindModeResult = (
-        'SQL'    => 'WHERE testa LIKE ? AND testb NOT LIKE ? AND testc = ?'
+        'SQL'    => 'WHERE testa LIKE ? AND testb NOT LIKE ? AND testc = ?',
         'Values' => ['a', 'b', 'c'],
     )
 
@@ -1389,12 +1625,12 @@ sub QueryCondition {
                         $WordSQL = "'" . $WordSQL . "'";
                     }
 
-        # check if database supports LIKE in large text types
-        # the first condition is a little bit opaque
-        # CaseSensitive of the database defines, if the database handles case sensitivity or not
-        # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
-        # so if the database dont support case sensitivity or the configuration of the customer database want to do this
-        # then we prevent the LOWER() statements.
+    # check if database supports LIKE in large text types
+    # the first condition is a little bit opaque
+    # CaseSensitive of the database defines, if the database handles case sensitivity or not
+    # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
+    # so if the database doesn't support case sensitivity or the configuration of the customer database wants to do this
+    # then we prevent the LOWER() statements.
                     if ( !$Self->GetDatabaseFunction('CaseSensitive') || $CaseSensitive ) {
                         $SQLA .= "$Key $Type $WordSQL";
                     }
@@ -1438,12 +1674,12 @@ sub QueryCondition {
                         $WordSQL = "'" . $WordSQL . "'";
                     }
 
-        # check if database supports LIKE in large text types
-        # the first condition is a little bit opaque
-        # CaseSensitive of the database defines, if the database handles case sensitivity or not
-        # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
-        # so if the database dont support case sensitivity or the configuration of the customer database want to do this
-        # then we prevent the LOWER() statements.
+     # check if database supports LIKE in large text types
+     # the first condition is a little bit opaque
+     # CaseSensitive of the database defines, if the database handles case sensitivity or not
+     # and the parameter $CaseSensitive defines, if the customer database should do case sensitive statements or not.
+     # so if the database doesn't support case sensitivity or the configuration of the customer database want to do this
+     # then we prevent the LOWER() statements.
                     if ( !$Self->GetDatabaseFunction('CaseSensitive') || $CaseSensitive ) {
                         $SQLA .= "$Key $Type $WordSQL";
                     }
